%global gem_name database_cleaner

Summary: Strategies for cleaning databases
Name: rubygem-%{gem_name}
Version: 1.1.1
Release: 1%{?dist}
Group: Development/Languages
License: MIT
URL: http://github.com/bmabey/database_cleaner
Source0: http://rubygems.org/gems/%{gem_name}-%{version}.gem
Requires: ruby(rubygems)
Requires: ruby(release)
BuildRequires: mongodb-server
BuildRequires: rubygems-devel
BuildRequires: rubygem(activerecord)
BuildRequires: rubygem(mongo)
BuildRequires: rubygem(moped)
# Redis is not yet vailable in Fedora.
# https://bugzilla.redhat.com/show_bug.cgi?id=978284
#BuildRequires: rubygem(redis)
BuildRequires: rubygem(rspec)
BuildRequires: rubygem(sequel)
BuildRequires: rubygem(sqlite3)
BuildArch: noarch
Provides: rubygem(%{gem_name}) = %{version}

%description
The original use case was to ensure a clean state during tests. Each strategy
is a small amount of code but is code that is usually needed in any ruby app
that is testing with a database

%package	doc
Summary:        Documentation for %{gem_name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}

%description    doc
This package contains documentation for %{gem_name}

%prep
%setup -q -c -T
%gem_install -n %{SOURCE0}

%build

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

chmod -x %{buildroot}%{gem_libdir}/database_cleaner/active_record/truncation.rb
chmod -x %{buildroot}%{gem_libdir}/database_cleaner/sequel/truncation.rb
chmod -x %{buildroot}%{gem_instdir}/examples/Gemfile

%check
pushd .%{gem_instdir}

# Bundler just complicates everything in our case, remove it.
sed -i 's|require "bundler"||' spec/spec_helper.rb
sed -i 's|Bundler.setup||' spec/spec_helper.rb

# This tests fail due to change in RSpec 2.13+.
# https://github.com/bmabey/database_cleaner/issues/238
sed -i '/raise_error(NotImplementedError)/{s/^/#/}' spec/database_cleaner/generic/truncation_spec.rb

# Some tests fail due to changes in AR 4.0.
# https://github.com/bmabey/database_cleaner/issues/237
sed -i '/\.should_receive(:increment_open_transactions)/{s/^/#/}' spec/database_cleaner/active_record/transaction_spec.rb
sed -i '/\.should_receive(:decrement_open_transactions)/{s/^/#/}' spec/database_cleaner/active_record/transaction_spec.rb

# Disable "DatabaseCleaner::Mongo::Truncation truncates all collections by
# default". There is some weird comment about MongoDB etc. Needs investigation.
sed -i '/expected_counts\.each/,/end/ {s/^/#/}' spec/database_cleaner/mongo/truncation_spec.rb

mkdir db
touch db/config.yml

# Disable MySql and Postres adapters for now. They need more configuration
# probably.
sed -i '/active_record\/connection_adapters\/mysql/{s/^/#/}' spec/database_cleaner/active_record/truncation_spec.rb
sed -i '/active_record\/connection_adapters\/post/{s/^/#/}' spec/database_cleaner/active_record/truncation_spec.rb
sed -i 's/\[MysqlAdapter, Mysql2Adapter, SQLite3Adapter, JdbcAdapter, PostgreSQLAdapter, IBM_DBAdapter\]/\[SQLite3Adapter\]/' \
  spec/database_cleaner/active_record/truncation_spec.rb

# Start MongoDB
mongod --dbpath=. --logpath ./mongod.log --fork

rspec \
  spec/database_cleaner/active_record/*_spec.rb \
  spec/database_cleaner/generic \
  spec/database_cleaner/mongo \
  spec/database_cleaner/moped \
  spec/database_cleaner/sequel \

# Quit MongoDB
kill -INT `cat mongod.lock`

popd

%files
%dir %{gem_instdir}
%{gem_libdir}
%doc %{gem_instdir}/LICENSE
%doc %{gem_instdir}/README.markdown
%{gem_cache}
%{gem_spec}

%files doc
%{gem_docdir}
%{gem_instdir}/Gemfile.lock
%doc %{gem_instdir}/TODO
%doc %{gem_instdir}/examples
%{gem_instdir}/spec
%{gem_instdir}/features
%doc %{gem_instdir}/History.rdoc
%{gem_instdir}/*.yml
%{gem_instdir}/Rakefile

%changelog
* Mon Aug 19 2013 Vít Ondruch <vondruch@redhat.com> - 1.1.1-1
- Update to database_cleaner 1.1.1.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.6-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Mar 21 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.6-7
- Rebuild for https://fedoraproject.org/wiki/Features/Ruby_2.0.0

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.6-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Feb 01 2012 Vít Ondruch <vondruch@redhat.com> - 0.6.6-4
- Rebuilt for Ruby 1.9.3.

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jul 01 2011 Vít Ondruch <vondruch@redhat.com> - 0.6.6-2
- Fixed -doc subpackage dependency.

* Mon Mar 21 2011 Vít Ondruch <vondruch@redhat.com> - 0.6.6-1
- Updated upstream version.

* Mon Mar 21 2011 Vít Ondruch <vondruch@redhat.com> - 0.5.2-2
- Added tests.

* Wed Oct 06 2010 Jozef Zigmund <jzigmund@redhat.com> - 0.5.2-1
- Initial package
